
***********************************************
*GLASS* --- Generator for Large Scale Structure
***********************************************

.. image:: _static/spheres.png

GLASS, the generator for large scale structure, is a library for performing the
kind of simulation that is useful in the field of cosmology.  As the name
suggests, the code was originally designed to simulate cosmic matter, weak
gravitational lensing, and galaxy positions.  But GLASS is really a platform
for a wide range of cosmological and astrophysical simulations on the sphere,
thanks to its ultra-flexible design and open architecture.


=================
Table of Contents
=================

.. toctree::
   :maxdepth: 2

   manual/index
   Examples <https://glass.readthedocs.io/projects/examples/>
   user/index
   reference/index


==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
